# Welcome to Crash Catcher's Documentation

Crash Catcher is a decorator to catch exceptions in a python function and log them to a file. Supports optional callbacks to perform cleanup operations before the crash log is written.

## Source Code

The source code for this project is available on [GitHub](https://github.com/RhetTbull/crash-catcher).

## Installation

or via pip:

```bash
    python3 -m pip install crash-catcher 
```

## License

Crash Catcher is published under the [MIT license](https://mit-license.org/), Copyright (c) 2023, Rhet Turnbull.
